@@ -52,7 +52,12 @@ class StreamClient(object):
         '''
         validate_feed(feed_id)
         from stream.feed import Feed
-        return Feed(self, feed_id)
+        
+        # generate the token
+        feed_together = feed_id.replace(':', '')
+        token = sign(self.api_secret, feed_together)
+        
+        return Feed(self, feed_id, token)
 
     def get_default_params(self):
         '''
@@ -61,23 +66,14 @@ class StreamClient(object):
         params = dict(api_key=self.api_key)
         return params
 
-    def get_headers(self, feed):
-        '''
-        Returns the headers with the signed authorization key
-        '''
-        feed = feed.replace(':', '')
-        signature = sign(self.api_secret, feed)
-        headers = {'Authorization': '%s %s' % (feed, signature)}
-        return headers
-
-    def _make_request(self, method, relative_url, feed, params=None, data=None):
+    def _make_request(self, method, relative_url, authorization, params=None, data=None):
         params = params or {}
         data = data or {}
 
         default_params = self.get_default_params()
         default_params.update(params)
 
-        headers = self.get_headers(feed)
+        headers = headers = {'Authorization': authorization}
         url = self.base_url + relative_url
 
         response = method(url, data=data, headers=headers,
