@@ -3,7 +3,7 @@ from stream.utils import validate_feed
 
 class Feed(object):
 
-    def __init__(self, client, feed_id):
+    def __init__(self, client, feed_id, token):
         '''
         Initializes the Feed class
         
@@ -16,6 +16,8 @@ class Feed(object):
         self.feed_id = feed_id
         self.feed_url = 'feed/%s/' % feed_id.replace(':', '/')
         self.feed_together = feed_id.replace(':', '')
+        self.token = token
+        self.authorization = self.feed_together + ' ' + self.token
 
     def add_activity(self, activity_data):
         '''
@@ -30,7 +32,7 @@ class Feed(object):
             activity_id = feed.add_activity(activity_data)
         '''
         result = self.client.post(
-            self.feed_url, data=activity_data, feed=self.feed_id)
+            self.feed_url, data=activity_data, authorization=self.authorization)
         return result
 
     def remove_activity(self, activity_id):
@@ -41,7 +43,7 @@ class Feed(object):
         (note this will also remove the activity from feeds which follow this feed)
         '''
         url = self.feed_url + '%s/' % activity_id
-        result = self.client.delete(url, feed=self.feed_id)
+        result = self.client.delete(url, authorization=self.authorization)
         return result
 
     def follow(self, target_feed):
@@ -53,7 +55,7 @@ class Feed(object):
         validate_feed(target_feed)
         url = self.feed_url + 'follows/'
         response = self.client.post(
-            url, data=dict(target=target_feed), feed=self.feed_id)
+            url, data=dict(target=target_feed), authorization=self.authorization)
         return response
 
     def unfollow(self, target_feed):
@@ -62,7 +64,7 @@ class Feed(object):
         '''
         validate_feed(target_feed)
         url = self.feed_url + 'follows/%s/' % target_feed
-        response = self.client.delete(url, feed=self.feed_id)
+        response = self.client.delete(url, authorization=self.authorization)
         return response
 
     def get(self, **params):
@@ -78,5 +80,5 @@ class Feed(object):
             feed.get(limit=10, offset=10)
         '''
         response = self.client.get(
-            self.feed_url, params=params, feed=self.feed_id)
+            self.feed_url, params=params, authorization=self.authorization)
         return response
